#ifndef RADIOSTATION_H
#define RADIOSTATION_H

#include <QString>

class RadioStation
{
public:
    RadioStation();

    void setName(QString);
    void setUrl(QString);
    void setGenre(QString);
    void setCountry(QString);

    QString getName();
    QString getUrl();
    QString getGenre();
    QString getCountry();

private:
    QString name;
    QString url;
    QString genre;
    QString country;


};

#endif // RADIOSTATION_H
